import Service from '@ember/service';
export declare type ImageType = 'png' | 'jpeg' | 'webp' | 'avif';
export interface LqipBase {
    type: string;
}
export interface LqipInline extends LqipBase {
    type: 'inline';
    class: string;
}
export interface LqipColor extends LqipBase {
    type: 'color';
    class: string;
}
export interface LqipBlurhash extends LqipBase {
    type: 'blurhash';
    hash: string;
    width: number;
    height: number;
}
export interface ImageMeta {
    image: string;
    width: number;
    height: number;
    type: ImageType;
}
export interface Meta {
    widths: number[];
    formats: ImageType[];
    aspectRatio: number;
    fingerprint?: string;
    lqip?: LqipInline | LqipColor | LqipBlurhash;
}
/**
 * Service class to provides images generated by the responsive images package
 */
export default class ResponsiveImageService extends Service {
    /**
     * the screen's width
     * This is the base value to calculate the image size.
     * That means the {{#crossLink "Services/ResponsiveImage:getImageBySize"}}getImageBySize{{/crossLink}} will return
     * an image that's close to `screenWidth *  window.devicePixelRatio * size / 100`
     */
    screenWidth: number;
    /**
     * the physical width
     */
    physicalWidth: number;
    /**
     * return the images with the different widths
     */
    getImages(imageName: string, type?: ImageType): ImageMeta[];
    getMeta(imageName: string): Meta;
    private normalizeImageName;
    private getType;
    getAvailableTypes(imageName: string): ImageType[];
    /**
     * returns the image data which fits for given size (in vw)
     */
    getImageMetaBySize(imageName: string, size?: number, type?: ImageType): ImageMeta | undefined;
    /**
     * returns the image data which fits for given width (in px)
     */
    getImageMetaByWidth(imageName: string, width: number, type?: ImageType): ImageMeta;
    getAspectRatio(imageName: string): number;
    getImageFilename(image: string, width: number, format: ImageType): string;
    private getDestinationWidthBySize;
    private _meta?;
    /**
     * the meta values from build time
     */
    get meta(): Record<string, Meta>;
    set meta(meta: Record<string, Meta>);
}
